@@ -1,5 +1,5 @@
 # from SCoinAPI import centralbank
-from SCoinAPI.SCoinAPI import centralbank
+from SCoinAPI import centralbank
 
 cb = centralbank.Central_Bank()
 # res = ck.send_token('nUjymFTzrJcuqizbswdKACJtpRwMZtEkwXzQDxBk','cb','marmotbank',40)
@@ -8,7 +8,7 @@ cb = centralbank.Central_Bank()
 # res = ck.get_balance('marmotbank')
 # res = cb.get_balance('marmotbank')
 # print(res)
-res = cb.remove_layer1('marmotbank','fengtingjiayingweijie')
+# res = cb.remove_layer1('marmotbank','fengtingjiayingweijie')
 
 # import requests
 # link = 'http://52.44.57.177:8888/'
